@@ -190,12 +190,15 @@ class OpenEuler():
                 yield repo_name, repo_url
 
     def get_rpm_name_from_full_name(self, rpm):
-        pattern = r"^(.+?)-\d"
-        match = re.match(pattern, rpm)
+        pattern = r"^(.+?)-(?=(\d|svn|rc|beta|alpha)\w*(\.|-|\d|$))"
+        match = re.match(pattern, rpm, re.IGNORECASE)  # 忽略大小写（兼容SVN/Rc等）
+
         if match:
-            return match.group(1)
+            pkg_name = match.group(1)
+            log.debug(f"Extracted RPM name: {pkg_name} from full name: {rpm}")
+            return pkg_name
         else:
-            log.warning(f"{rpm} does not match the pattern")
+            log.warning(f"{rpm} does not match the RPM name pattern (expected: 包名-版本)")
             return None
 
     def get_openEuler_pkgs(
@@ -291,7 +294,7 @@ class OpenEuler():
 
     def get_openEuler_all_rpm_list(self, os_version: str, os_arch: str):
         """
-        获取指定版本、架构的所有 RPM 包完整名称。
+        获取指定版本、架构的所有 RPM 包完整名称。s
 
         Args:
             os_version: openEuler 版本号（如 "24.03-LTS-SP2"）
@@ -320,16 +323,18 @@ class OpenEuler():
 if __name__ == "__main__":
     # 初始化获取器
     oe = OpenEuler()
-    rs=oe.get_openEuler_everything_rpm_list("24.03-LTS-SP2", "x86_64")
-    print(f"everything {len(rs)} pkgs")
-    rs=oe.get_openEuler_epol_rpm_list("24.03-LTS-SP2", "x86_64")
-    print(f"epol {len(rs)} pkgs")
-    rs=oe.get_openEuler_update_rpm_list("24.03-LTS-SP2", "x86_64")
-    print(f"update {len(rs)} pkgs")
-    rs=oe.get_openEuler_os_rpm_list("24.03-LTS-SP2", "x86_64")
-    print(f"os {len(rs)} pkgs")
-    rs=oe.get_openEuler_all_rpm_list("24.03-LTS-SP2", "x86_64")
-    print(f"total {len(rs)} pkgs")
+    # rpm=oe.get_rpm_name_from_full_name("texlive-footbib-svn17115.2.0.7.rpm")
+    # print(rpm)
+    # rs=oe.get_openEuler_everything_rpm_list("24.03-LTS-SP2", "x86_64")
+    # print(f"everything {len(rs)} pkgs")
+    # rs=oe.get_openEuler_epol_rpm_list("24.03-LTS-SP2", "x86_64")
+    # print(f"epol {len(rs)} pkgs")
+    # rs=oe.get_openEuler_update_rpm_list("24.03-LTS-SP2", "x86_64")
+    # print(f"update {len(rs)} pkgs")
+    # rs=oe.get_openEuler_os_rpm_list("24.03-LTS-SP2", "x86_64")
+    # print(f"os {len(rs)} pkgs")
+    # rs=oe.get_openEuler_all_rpm_list("24.03-LTS-SP2", "x86_64")
+    # print(f"total {len(rs)} pkgs")
 
     # count=0
     # effective_count=0
